# chercher-plugin-epub

[Chercher](https://github.com/dnlzrgz/chercher) plugin that adds support for EPUB files thanks to [PyMuPDF](https://pymupdf.readthedocs.io/en/latest/).

## Installation

> [!NOTE]
> This plugin is included with Chercher by default, so no additional installation is necessary

## Settings

> [!NOTE]
> This plugin does not requires any additional settings.
